0.8.3 (2020-10-27)
------------------

- Generate a wheel. For real. Or so I hope...


0.8.2 (2020-10-27)
------------------

- Fix generation of wheel on release. Only a tarball was released, now
  a wheel should be released as well.

- Fix compatibility with git < 2.7 in ``check-branches``.


0.8.1 (2020-10-26)
------------------

- Fix xUnit output that contained control characters when
  ``check-fixmes`` or ``check-branches`` were not run with the
  ``--no-color`` option.


0.8.0 (2020-10-22)
------------------

First public release.


0.1.0 (2016-01-12)
------------------

First apparition in a private tool.
